@@ -253,7 +253,8 @@ sub unit_label {
   my $abs = abs($value);
 
   my $label;
-  $label = $abs >= 1e9  ? sprintf("%.4g G%s",$value/1e9,$unit)
+  $label = $unit =~ /^[kcM]/ ? sprintf("%.4g %s",$value,$unit)
+         : $abs >= 1e9  ? sprintf("%.4g G%s",$value/1e9,$unit)
          : $abs >= 1e6  ? sprintf("%.4g M%s",$value/1e6,$unit)
          : $abs >= 1e3  ? sprintf("%.4g k%s",$value/1e3,$unit)
 	 : $abs >= 1    ? sprintf("%.4g %s", $value,    $unit)
@@ -572,9 +573,14 @@ sub show_section {  # one of instructions, upload_tracks, search, overview, regi
     return $setting eq 'hide' || $setting eq 'off' ? 0 : 1;
 }
 
+sub unit_divider {
+    my $self = shift;
+    return $self->global_setting('unit_divider') || 1;    
+}
+
 sub get_ranges {
   my $self      = shift;
-  my $divisor   = $self->global_setting('unit_divider') || 1;
+  my $divisor   = $self->unit_divider;
   my $rangestr  = $self->global_setting('zoom levels')  || '100 1000 10000 100000 1000000 10000000';
   if ($divisor == 1 ) {
     return split /\s+/,$rangestr;
@@ -637,7 +643,7 @@ sub feature2label {
     || eval{$feature->source_tag} || eval{$feature->primary_tag} or return;
 
   my $dbid = eval{$feature->gbrowse_dbid};
-
+  
   (my $basetype = $type) =~ s/:.+$//;
   my @label = $self->type2label($type,$length,$dbid);
   push @label,$self->type2label($basetype,$length,$dbid);
@@ -653,6 +659,7 @@ sub invert_types {
   my $self    = shift;
   my $config  = shift;
   return unless $config;
+
   my %inverted;
   for my $label (keys %{$config}) {
     my $feature = $self->setting($label => 'feature') or next;
@@ -783,6 +790,11 @@ sub db_settings {
 
   $track ||= 'general';
 
+  if ($track =~ /(.+):(\d+)$/) {  # in the case that we get called with foo:499
+      $track  = $1;
+      $length = $2;
+  }
+
   # caching to avoid calling setting() too many times
   my $semantic_label = $self->semantic_label($track,$length);
 
@@ -1165,7 +1177,7 @@ sub _setting {
 sub code_setting {
     my $self    = shift;
     my $base = $self->{_user_tracks};
-    if ($base && exists $base->{config}{$_[0]}) {
+    if ($base && exists $base->{config}{$_[0]||''}) {
 	return $self->_setting(@_);  # don't allow code_setting on user tracks
     } else {
  	return $self->SUPER::code_setting(@_);
