@@ -7,7 +7,7 @@ package Bio::Graphics::Browser2::TrackDumper;
 #
 ###################################################################
 
-# $Id: TrackDumper.pm 23501 2010-06-29 19:45:54Z lstein $
+# $Id: TrackDumper.pm 23707 2010-08-27 14:56:28Z lstein $
 
 # Simple track dumper, suitable for a lightweight replacement to DAS.
 # Call this way:
@@ -55,6 +55,13 @@ sub new {
 
 sub forced_format { shift->{format} }
 
+sub add_prefix {
+    my $self = shift;
+    return $self->{'.prefix'} if exists $self->{'.prefix'};
+    my $datasource = $self->data_source;
+    return $self->{'.prefix'} = $datasource->seqid_prefix;
+}
+
 sub print_stylesheet {
     my $self = shift;
     my ($segment,$labels) = @_;
@@ -77,7 +84,7 @@ sub dump_track {
     my $db     = $source->open_database($label);
     my @types  = shellwords($source->setting($label=>'feature'));
 
-    my $dump_method = $self->guess_dump_method($db);
+    my $dump_method = $self->guess_dump_method($db,$label);
     $self->$dump_method($db,$segment,\@types,$label);
 
 }
@@ -90,9 +97,13 @@ sub dump_gff3 {
     shift->_dump_gff3(@_);
 }
 
+sub dump_vista {
+    shift->_dump_gff3(@_,1,1);
+}
+
 sub _dump_gff3 {
     my $self = shift;
-    my ($db,$segment,$types,$label,$autowig) = @_;
+    my ($db,$segment,$types,$label,$autowig,$vista) = @_;
 
     my @args = $segment ? (-seq_id=> $segment->seq_id,
 			   -start => $segment->start,
@@ -107,20 +118,28 @@ sub _dump_gff3 {
     #    a UCSC wigfile upload (using bedgraph format).
     # 2) otherwise we print out a valid gff3 file
 
-    my ($gff3_header,%wigs);
+    my ($gff3_header,$bed_header,%peaks,%wigs,%bigwigs);
     while (my $f = $iterator->next_seq) {
-	if ($autowig && (my ($wig) = $f->get_tag_values('wigfile'))) {
+	if (($autowig || $vista) && (my ($wig) = $f->get_tag_values('wigfile'))) {
 	    my ($start,$end) = ($f->start,$f->end);
 	    $start           = $segment->start if $segment && $start < $segment->start;
 	    $end             = $segment->end   if $segment && $end   > $segment->end;
-	    $wigs{$f->display_name || $f->type}{$f->seq_id}{$wig} = [$start,$end];
+	    my $w = $wig =~ /\.bw$/ ? \%bigwigs : \%wigs;
+	    my $trackname = $f->display_name || $f->type;
+	    $trackname    .= " (Signal)" if $vista;
+	    $w->{$trackname}{$f->seq_id}{$wig} = [$start,$end];
 	} else {
 	    $self->print_gff3_header($segment) unless $gff3_header++;
 	    $self->print_feature($f);
 	}
+	if ($vista && (my ($peaks) = $f->get_tag_values('peak_type'))) {
+	    $peaks{$f->display_name || $f->type}{$peaks} = [$segment->seq_id,$segment->start,$segment->end];
+	}
     }
 
+    $self->print_peaks($db,\%peaks,$label)        if %peaks;
     $self->print_bio_graphics_wigs(\%wigs,$label) if %wigs;
+    $self->print_bigwigs(\%bigwigs,$label)        if %bigwigs;
 }
 
 sub dump_sam {
@@ -136,22 +155,15 @@ sub dump_sam {
 
     my $header = $db->header;
 
+    my $prefix = $self->add_prefix;
+    my $seq_id  = $segment->seq_id;
+    $seq_id     = "$prefix$seq_id" if $prefix;
+
     print $header->text;
-
-    my $build   = $self->data_source->build_id;
-    my $species = $self->data_source->species;
-    my @fields;
-    push @fields,"SP:$species" if $species;
-    push @fields,"AS:$build"   if $build;
-
-    for my $seqid ($db->seq_ids) {
-	my $length = $db->length($seqid) or next;
-	print "\@SQ\tSN:$seqid\tLN:$length\t",join("\t",@fields),"\n";
-    }
-
     print "\@CO\t$key\n";
     print "\@CO\tGenerated by GBrowse from ",$self->origin($label),"\n";
-    print "\@CO\tSequence-region ",$segment->seq_id,':',$segment->start,'..',$segment->end,"\n" if $segment;
+    print "\@CO\tSequence-region ",$seq_id,':',$segment->start,'..',$segment->end,"\n" if $segment;
+
 
     # there are problems with the filehandle-based conversion of 
     # BAM to TAM because the low-level functions write to STDOUT directly
@@ -162,7 +174,11 @@ sub dump_sam {
     if (modperl_request()) {
 	if (Bio::DB::Bam::AlignWrapper->can('tam_line')) {
 	    my $iterator = $db->features(@args,-iterator=>1);
-	    print $_->tam_line,"\n" while $_ = $iterator->next_seq;
+	    while ($_ = $iterator->next_seq) {
+		my $tam_line = $_->tam_line;
+		$tam_line =~ s/^([^\t]+)\t([^\t}+)\t([^\t+])/$1\t$2\t$prefix$3/ if $prefix;
+		print $tam_line,"\n";
+	    }
 	} else {
 	    print "## Bio::DB::SamTools 1.19 or higher required for printing SAM data when running under mod_perl\n";
 	}
@@ -177,12 +193,14 @@ sub dump_sam {
 	my $child = Bio::Graphics::Browser2::Render->fork();
 	if ($child) {
 	    $pipe->reader();
-	    print while <$pipe>;
+	    while (<$pipe>) {
+		s/^([^\t]+)\t([^\t]+)\t([^\t]+)/$1\t$2\t$prefix$3/ if $prefix;
+		print $_;
+	    }
 	} else {
 	    $pipe->writer();
 	    my $fh = $db->features(@args,-fh  => 1);
 	    while (<$fh>) {
-		warn $_;
 		print $pipe $_ ;
 	    }
 	    exit 0;
@@ -192,7 +210,10 @@ sub dump_sam {
 
     # CGI scripts simply do it directly.
     my $fh = $db->features(@args,-fh  => 1);
-    print while <$fh>;
+	while (<$fh>) {
+		s/^([^\t]+)\t([^\t]+)\t([^\t]+)/$1\t$2\t$prefix$3/ if $prefix;
+	    print $_;
+	}
 }
 
 sub dump_bigwig {
@@ -216,14 +237,6 @@ sub dump_bigwig {
 
     my $last_type = '';
     my $last_name = '';
-    
-    my $build   = $self->data_source->build_id  || 'unknown';
-    my $species = $self->data_source->species;
-    my $taxid   = $self->data_source->taxon_id;
-    my $description = "Generated by GBrowse from $origin";
-    $description   .= "; species=$species" if $species;
-    $description   .= "; taxid=$taxid"     if $taxid;
-    $build         .= "; build=$build"     if $build;
 
     while (my $f = $iterator->next_seq) {
 	my $type = $f->type;
@@ -232,33 +245,67 @@ sub dump_bigwig {
 	if ($type ne $last_type or $name ne $last_name) {
 	    print "\n" if $last_type or $last_name;
 	    $name ||= $type;
-	    print qq(track type=wiggle_0 name="$key ($name)" description="$description"\n);
+	    print qq(track type=wiggle_0 name="$key ($name)" description="Generated by GBrowse from $origin"\n);
 	    $last_type = $type;
 	}
 
 	if ($f->can('get_seq_stream')) {  # a summary type; need to do recursive iteration
 	    my $i = $f->get_seq_stream(@location_args);
-	    while (my $g = $i->next_seq) { $self->print_bed_line($g) }
+	    while (my $g = $i->next_seq) { $self->print_bed_score($g) }
 	}
 	else {
-	    $self->print_bed_line($f);
+	    $self->print_bed_score($f);
 	}
     }
 }
 
-sub print_bed_line {
+sub print_peaks {
+    my $self           = shift;
+    my ($db,$peaks,$label) = @_;
+    for my $trackname (keys %$peaks) {
+	$self->print_bed_header("$trackname (Peaks)");
+	for my $type (keys %{$peaks->{$trackname}}) {
+	    my ($seqid,$start,$end) = @{$peaks->{$trackname}{$type}};
+	    my $iterator            = $db->get_seq_stream(-seq_id=> $seqid,
+							  -start => $start,
+							  -end   => $end,
+							  -type  => $type,
+							  );
+	    while (my $f = $iterator->next_seq) {
+		$self->print_bed_score($f);
+	    }
+	    
+	}
+	print "\n";
+    }
+}
+
+sub print_bed_header {
+    my $self = shift;
+    my $label = shift;
+    print "track name=\"$label\"\n";
+}
+
+sub print_bed_score {
     my $self = shift;
     my $f    = shift;
-    my $score = sprintf("%.4f",$f->score);
+    my $score = defined $f->score ? sprintf("%.4f",$f->score) : '';
     $score =~ s/0+$//;
-    print join ("\t",$f->seq_id,$f->start,$f->end,$score),"\n";
+    my $seq_id = $f->seq_id;
+    if (my $prefix = $self->add_prefix) {
+	$seq_id    = "$prefix$seq_id";
+    }
+	
+    print join ("\t",$seq_id,$f->start,$f->end,$score),"\n";
 }
 
 sub guess_dump_method {
     my $self = shift;
     my $db   = shift;
+    my $label= shift;
 
     return 'dump_gff3'   if $self->forced_format eq 'gff3';
+    return 'dump_vista'  if $self->data_source->code_setting($label => 'glyph') =~ /vista/i;
 
     return 'dump_gff3_autowig'   if $db->isa('Bio::DB::SeqFeature::Store');
     return 'dump_gff3_autowig'   if $db->isa('Bio::DB::GFF');
@@ -276,24 +323,14 @@ sub print_gff3_header {
     my $segment = shift;
 
     my $date = localtime;
-    my $source = $self->data_source;
-    my $build  = $self->data_source->build_id  || 'unknown';
-    my $name   = $self->data_source->species;
-    my $taxid  = $self->data_source->taxon_id;
-
-    my $ncbi   = 'http://www.ncbi.nlm.nih.gov/Taxonomy/Browser/wwwtax.cgi';
-
-    my $species =  $taxid ? "$ncbi?id=$taxid"
-	          :$name  ? "$ncbi?name=$name"
-		  :undef;
-
     print "##gff-version 3\n";
     print "##date $date\n";
     print "##source gbrowse gbgff gff3 dumper\n";
-    print "##species $species\n" if $species;
-    print "##genome-build $build\n";
     if ($segment) {
-	print "##sequence-region ",$segment->seq_id,':',$segment->start,'..',$segment->end,"\n";
+	my $prefix = $self->add_prefix;
+	my $seq_id  = $segment->seq_id;
+	$seq_id     = "$prefix$seq_id" if $prefix;
+	print "##sequence-region ",$seq_id,':',$segment->start,'..',$segment->end,"\n";
     }
 }
 
@@ -336,6 +373,34 @@ sub print_bio_graphics_wigs {
     }
 }
 
+sub print_bigwigs {
+    my $self = shift;
+    my ($wigs,$label) = @_;
+    my $source  = $self->data_source;
+
+    # may need the relative pathname to get the wigs (sometimes)
+    my $basedir = $source->code_setting($label=>'basedir');
+    $basedir    = $basedir->() if $basedir && ref($basedir) eq 'CODE'; # a bit awkward here
+
+    eval "use Bio::DB::BigWig"
+	unless Bio::DB::BigWig->can('new');
+
+    my $prefix = $self->add_prefix;
+    for my $track_name (keys %$wigs) {
+	for my $seqid (keys %{$wigs->{$track_name}}) {
+	    $seqid = "$prefix$seqid" if $prefix;
+	    for my $wigfile (keys %{$wigs->{$track_name}{$seqid}}) {
+		my ($start,$end) = @{$wigs->{$track_name}{$seqid}{$wigfile}};
+		my $path = File::Spec->rel2abs($wigfile,$basedir);
+		my $wig  = Bio::DB::BigWig->new($path) or next;
+		my $segment = Bio::Graphics::Feature->new(-seq_id=>$seqid,-start=>$start,-end=>$end);
+		$self->dump_bigwig($wig,$segment,[],$track_name);
+		print "\n";
+	    }
+	}
+    }
+}
+
 sub print_datafile {
     my $self = shift;
 
@@ -517,6 +582,10 @@ sub guess_file_type {
     my $glyph = $source->setting(      $label => 'glyph');
     my $db    = $source->open_database($label);
 
+    if ($glyph && $glyph =~ /vista/i) {
+	return 'bed';
+    }
+
     if ($glyph && $glyph =~ /wiggle/) {
 	return 'bed';
     }
@@ -619,6 +688,9 @@ sub print_feature {
     eval { $f->version(3) };
     my $s = $f->gff_string(1);    # the flag is for GFF3 subfeature recursion
     chomp $s;
+    if (my $prefix = $self->add_prefix) {
+	$s =~ s/^/$prefix/gm unless $s =~ /^$prefix/m;
+    }
     $s =~ s/\t\t/\t\.\t/g if $s;    # no empty columns
     $self->do_wigfile_substitution( \$s );
     print $s, "\n";
@@ -729,7 +801,6 @@ sub get_scan {
 	next unless    $config->fallback_setting($l => 'discoverable');
 	next if        $config->code_setting($l=>'global feature');
 	my $key      = $config->code_setting($l => 'key');
-	my $category = $config->code_setting($l => 'category');
 	my $citation = $config->code_setting($l => 'citation');
 	my $subtracks = $config->subtrack_scan_list($l);
 	$result .=  <<END;
@@ -739,7 +810,6 @@ END
     ;
     $result .=  "select   = @$subtracks\n" if $subtracks;
     $result .=  "citation = $citation\n"   if $citation;
-    $result .=  "category = $category\n"   if $category;
     $result .=  "\n";
     }
 return $result;
