@@ -1,6 +1,6 @@
 package Bio::Graphics::Browser2::UserTracks;
 
-# $Id: UserTracks.pm 23707 2010-08-27 14:56:28Z lstein $
+# $Id: UserTracks.pm 23766 2010-09-14 15:23:09Z lstein $
 use strict;
 use Bio::Graphics::Browser2::DataSource;
 use Bio::Graphics::Browser2::DataLoader;
@@ -9,6 +9,7 @@ use File::Basename 'basename';
 use File::Path 'mkpath','rmtree';
 use IO::File;
 use IO::String;
+use File::Temp 'tempdir';
 use POSIX ();
 use Carp 'croak';
 
@@ -334,6 +335,23 @@ sub upload_data {
     $self->upload_file($file_name,$io,$content_type,$overwrite);
 }
 
+sub upload_url {
+    my $self  = shift;
+    my $url   = shift;
+    my $dir   = tempdir(CLEANUP=>1);
+    my $path  = File::Spec->catfile($dir,basename($url));
+    eval "require LWP::UserAgent" unless LWP::UserAgent->can('new');
+    my $agent = LWP::UserAgent->new();
+    my $response = $agent->mirror($url,$path);
+    $response->is_success or die $response->status_line;
+    my $mime = $response->header('Content-type');
+    open my $fh,"<",$path;
+    my @args = $self->upload_file(basename($url),$fh,$mime,1);
+    unlink $path;
+    File::Temp::cleanup();
+    return @args;
+}
+
 sub upload_file {
     my $self = shift;
     my ($file_name,$fh,$content_type,$overwrite) = @_;
